@@ -11,8 +11,10 @@ fn main() -> Result<(), Box<dyn Error>> {
     println!("Config: {:#?}", config);
     let countries = api.get_countries().send()?;
     println!("Countries: {:?}", countries.len());
-    let stations = api.get_stations().name("jazz").send()?;
-    println!("Stations with name containing 'jazz': {:?}", stations.len());
+    let tags = vec!["jazz","classical"];
+    let stations = api.get_stations().tag_list(tags).send()?;
+    println!("Stations with tags containing 'jazz' and 'classical': {:?}", stations.len());
+    println!("First found station: {:#?}", stations[0].clicktimestamp_iso8601);
     let vote_result = api.station_vote(&stations[0].stationuuid)?;
     println!("Stations voted result: {:?}", vote_result);
     let click_result = api.station_click(&stations[0].stationuuid)?;
