@@ -1,10 +1,11 @@
-pub mod api;
-pub mod countrysearchbuilder;
-pub mod languagesearchbuilder;
-pub mod stationsearchbuilder;
-pub mod tagsearchbuilder;
+mod api;
+mod countrysearchbuilder;
+mod languagesearchbuilder;
+mod stationsearchbuilder;
+mod tagsearchbuilder;
 
 pub use api::RadioBrowserAPI;
 pub use countrysearchbuilder::CountrySearchBuilder;
 pub use languagesearchbuilder::LanguageSearchBuilder;
 pub use tagsearchbuilder::TagSearchBuilder;
+pub use stationsearchbuilder::StationSearchBuilder;
\ No newline at end of file
